<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.diskmanager!message" line="0"/>
			<source>Authentication is required to read disk information</source>
			<translation>Wymagane jest uwierzytelnienie, aby odczytywać informacje o dyskach</translation>
		</message>
		<message>
			<location filename="com.deepin.diskmanager!description" line="0"/>
			<source>Run Disk Manager Need Authentication</source>
			<translation>Run Disk Manager Need Authentication</translation>
		</message>
	</context>
</TS>